NodeConfig

Struct NodeConfig 

pub struct NodeConfig {
Show 25 fields pub script: Option<String>, pub agent: Option<String>, pub inline: Option<InlineAgentConfig>, pub agent_config: Option<String>, pub input: Option<String>, pub context: HashMap<String, String>, pub tools: Vec<ToolSpec>, pub mcp_servers: Vec<McpServerConfig>, pub script_config: Option<ScriptConfig>, pub fleet: Option<String>, pub condition: Option<String>, pub channel: Option<String>, pub message: Option<String>, pub thread_ts: Option<String>, pub wait_for_reaction: bool, pub timeout_seconds: Option<u32>, pub blocks: Option<Value>, pub url: Option<String>, pub method: Option<String>, pub headers: HashMap<String, String>, pub body: Option<Value>, pub duration: Option<String>, pub branches: Vec<String>, pub strategy: Option<JoinStrategy>, pub extra: HashMap<String, Value>,
}
Node configuration

Fields

script: Option<String>

Script to execute (shell or expression)

agent: Option<String>

Agent name to execute (reference to external agent)

inline: Option<InlineAgentConfig>

Inline agent configuration (structured) Use this to embed agent config directly in the flow

agent_config: Option<String>

Inline agent configuration (YAML string) - legacy

input: Option<String>

Input to the agent (can contain ${variable} references)

context: HashMap<String, String>

Context variables to pass to agent

tools: Vec<ToolSpec>

Tools available to the agent node These override or extend the agent’s default tools

mcp_servers: Vec<McpServerConfig>

MCP servers for the agent node These override or extend the agent’s default MCP servers

script_config: Option<ScriptConfig>

Script configuration for running shell commands or native tools Use this for deterministic operations that don’t need an LLM

fleet: Option<String>

Fleet name to execute (reference to external fleet)

condition: Option<String>

Condition expression

channel: Option<String>

Channel to send to

message: Option<String>

Message text

thread_ts: Option<String>

Thread timestamp (for replies)

wait_for_reaction: bool

Wait for reaction

timeout_seconds: Option<u32>

Timeout in seconds

blocks: Option<Value>

Block Kit blocks (Slack)

url: Option<String>

URL for HTTP requests

method: Option<String>

HTTP method

headers: HashMap<String, String>

HTTP headers

body: Option<Value>

HTTP body

duration: Option<String>

Duration to wait (e.g., “30s”, “5m”)

branches: Vec<String>

Branches for parallel execution

strategy: Option<JoinStrategy>

Join strategy

extra: HashMap<String, Value>

Additional configuration