pub struct ScriptConfig {
pub command: Option<String>,
pub tool: Option<String>,
pub action: Option<String>,
pub args: HashMap<String, Value>,
pub working_dir: Option<String>,
pub env: HashMap<String, String>,
pub timeout_seconds: Option<u32>,
pub parse: Option<ScriptOutputParse>,
pub pattern: Option<String>,
pub fail_on_error: bool,
}Expand description
Script node configuration for non-LLM deterministic operations This enables running shell commands, native tools, or custom SDK tools
Fields
command: Option<String>Shell command to execute Supports variable substitution: ${previous.output}, ${node_id.field}
tool: Option<String>Built-in tool to execute (e.g., “docker”, “kubectl”, “http”) These are native Rust implementations, no LLM required
action: Option<String>Tool action (e.g., “ps”, “logs”, “get”)
args: HashMap<String, Value>Arguments for the tool or command
working_dir: Option<String>Working directory for command execution
env: HashMap<String, String>Environment variables
timeout_seconds: Option<u32>Timeout in seconds (default: 60)
parse: Option<ScriptOutputParse>How to parse the output: “text”, “json”, “lines”, “regex”
pattern: Option<String>Regex pattern for parsing (when parse = “regex”)
fail_on_error: boolWhether to fail the flow if command returns non-zero exit code